using System;
using System.Collections.Generic;
using System.Text;
using EPiServer;
using EPiServer.Core;
using EPiServer.DataAbstraction;
using EPiServer.Web.PropertyControls;
using EPiServer.Web.WebControls;
using EPiServer.Core.PropertySettings;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using EPiServer.PlugIn;

namespace EPiServer.PropertyTypes
{
    /// <summary>
    /// PropertyControl implementation used for rendering DropDownList data.
    /// </summary>
    [PropertySettings(typeof(MySettings))]
    public class IntroControl : EPiServer.Web.PropertyControls.PropertyLongStringControlBase
    {
        private TextBox _textArea;
        private string DIALOG_JS_KEY = "IntroPropertyControl_Js_Key";
        //private const int maxLength = 300;
        //private const int rowCount = 4;


        /// <summary>
        /// Gets the DropDownList instance for this IPropertyControl.
        /// </summary>
        /// <value>The property that is to be displayed or edited.</value>
        public IntroProperty IntroProperty
        {
            get
            {
                return PropertyData as IntroProperty;
            }
        }

        public override void CreateEditControls()
        {
            // Create a div to hold message about remaining characters
            HtmlGenericControl _divCtrl = new HtmlGenericControl("div");

            _textArea = new TextBox();
            _textArea.Text = this.ToString();
            _textArea.Width = 500;

            MySettings _mySettings = IntroProperty.GetSetting(typeof(MySettings)) as MySettings;

            _textArea.MaxLength = _mySettings.MaxLength;
            _textArea.TextMode = _mySettings.RowCount > 1 ? TextBoxMode.MultiLine : TextBoxMode.SingleLine;
            _textArea.Rows = _mySettings.RowCount;

            // add controls
            this.Controls.Add(_textArea);
            this.Controls.Add(new HtmlGenericControl("br"));
            this.Controls.Add(_divCtrl);          
  
            if(string.IsNullOrEmpty(_textArea.Text))
                _divCtrl.InnerHtml = "You have " + _mySettings.MaxLength + " characters left.";
            
            // Add js attribute for onkeyup
            _textArea.Attributes.Add("onkeyup",
                string.Format("limitChars('{0}', {1}, '{2}')", _textArea.ClientID, _mySettings.MaxLength, _divCtrl.ClientID));

            // Register js function for counting characters left
            if (!Page.ClientScript.IsStartupScriptRegistered(this.GetType(), DIALOG_JS_KEY))
               Page.ClientScript.RegisterStartupScript(this.GetType(), DIALOG_JS_KEY, GetJsFunction());            
            
        }


        private string GetJsFunction()
        {
            return
                @"<script type='text/javascript'>
                   <!--
                    function limitChars(textId, limit, infodiv)
                    {
                        var textarea = document.getElementById(textId);
                        var text = textarea.value; 
                        var textlength = text.length;
                        var info = document.getElementById(infodiv);
                     
                        if(textlength >= limit)
                        {
                            info.innerHTML = 'Maximum number of characters is '+limit+'!';
                            textarea.value = text.substr(0,limit);
                            return false;
                        }
                        else
                        {
                            info.innerHTML = 'You have '+ (limit - textlength) +' characters left.';
                            return true;
                        }
                    }
                    //-->
                </script>";
        }

        public override void ApplyEditChanges()
        {
            SetValue(_textArea.Text);
        }
    }

    /// <summary>
    /// Custom PropertyData implementation
    /// </summary>
    [Serializable]
    [PageDefinitionTypePlugIn(DisplayName = "IntroductionText", Description = "Introduction text, configurable length")]
    public class IntroProperty : EPiServer.Core.PropertyLongString
    {
        public override EPiServer.Core.IPropertyControl CreatePropertyControl()
        {
            return new IntroControl();
        }
    }
}
