﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using EPiServer.Core.PropertySettings;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace EPiServer.PropertyTypes
{
    [PropertySettingsUI(AdminControl = typeof(MySettingsUI))]
    public class MySettings : PropertySettingsBase
    {
        public int MaxLength { get; set; }
        public int RowCount { get; set; }
       

        public override IPropertySettings GetDefaultValues()
        {
            return new MySettings() { MaxLength = 300, RowCount = 4 };
        }
    }

    public class MySettingsUI : PropertySettingsControlBase
    {

        private TextBox _lengthInput;
        private TextBox _rowsInput;

        protected override void CreateChildControls()
        {

            base.CreateChildControls();
            // Add textbox and label for maxCount
            _lengthInput = new TextBox { ID = "MaxCount", Width = 40 };
            Label label = new Label { Text = "Maximum text length : ", AssociatedControlID = "MaxCount" };
            Controls.Add(label);
            Controls.Add(_lengthInput);

            Controls.Add(new HtmlGenericControl("br"));

            // Add textbox and label for rows
            _rowsInput = new TextBox { ID = "Rows", Width = 40 };
            Label label2 = new Label { Text = "Rowcount: ", AssociatedControlID = "Rows" };
            Controls.Add(label2);
            Controls.Add(_rowsInput); 
       
        }
       

        public override void LoadSettingsUI(IPropertySettings settings)
        {

            EnsureChildControls();
            int maxLength = ((MySettings)settings).MaxLength;
            int rowCount = ((MySettings)settings).RowCount;
            if (maxLength > 0)
                _lengthInput.Text = maxLength.ToString();
            if (rowCount > 0)
                _rowsInput.Text = rowCount.ToString();
       
        }

        public override void UpdateSettings(IPropertySettings settings)
        {

            EnsureChildControls();
            if (!string.IsNullOrEmpty(_lengthInput.Text))
                ((MySettings)settings).MaxLength = Int32.Parse(_lengthInput.Text);
            if (!string.IsNullOrEmpty(_rowsInput.Text))
                ((MySettings)settings).RowCount = Int32.Parse(_rowsInput.Text);
       
        }
    }

}
