﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using EPiServer.Shell.Search;
using System.Web.Security;
using EPiServer;
using EPiServer.Security;
using System.ComponentModel.Composition;
using EPiServer.Personalization;
using EPiServer.Shell.Web.Mvc.Html;

namespace Demo.UserSearchProvider
{
    [Export (typeof(ISearchProvider))]
    public class UserSearch : ISearchProvider
    {
        #region ISearchProvider Members

        /// <summary>
        /// Area that the provider mapps to, used for spotlight searching
        /// </summary>
        public string Area
        {
            get { return "CMS"; }
        }

        /// <summary>
        /// The category that the provider returns hits in
        /// </summary>
        public string Category
        {
            get { return "Users"; }
        } 

        public IEnumerable<SearchResult> Search(Query query)
        {
            List<SearchResult> results = new List<SearchResult>();

            //Since each hit will link to admin mode, we need to check access rights
            if (!PrincipalInfo.HasAdminAccess)
                return results;

            //Get the wildcardsymbol for the providers
            string wildcardSymbol = GetWildCardSymbol();

            string searchQuery = query.SearchQuery + wildcardSymbol;

            //Search for users using userName
            int totalRecords = 0;
            MembershipUserCollection membershipHits = Membership.FindUsersByName(searchQuery, 0, 10, out totalRecords);

            foreach (MembershipUser user in membershipHits)
            {
                //Do not exceed maximum number of results
                if (results.Count < query.MaxResults)
                {
                    AddUser(user, results);
                }
            }

            if (results.Count < query.MaxResults)
            {
                //Search by emailadress
                membershipHits = Membership.FindUsersByEmail(searchQuery, 0, 10, out totalRecords);
                foreach (MembershipUser user in membershipHits)
                {
                    //Do not exceed maximum number of results
                    if (results.Count < query.MaxResults)
                    {
                        AddUser(user, results);
                    }
                }
            }

            return results;
        }


        private static void AddUser(MembershipUser user, IList<SearchResult> results)
        {
            string url = UriSupport.ResolveUrlFromUIBySettings("Admin/EditUser.aspx?membershipUsername=" + user.UserName + "&Provider=" + user.ProviderName);

            bool exist = results.FirstOrDefault(r => r.Url == url) != null;

            if (!exist)
            {
                SearchResult result = new SearchResult(url, user.UserName, user.Email);
                // Add profile data as tooltip information 
                EPiServerProfile epiProfile = EPiServerProfile.Get(user.UserName);
                if (epiProfile != null)
                {
                    if (!string.IsNullOrEmpty(epiProfile.LastName))
                        result.ToolTipElements.Add(new ToolTipElement("LastName", epiProfile.LastName));
                    if (!string.IsNullOrEmpty(epiProfile.FirstName))
                        result.ToolTipElements.Add(new ToolTipElement("FirstName", epiProfile.FirstName));
                    if (!string.IsNullOrEmpty(epiProfile.Company))
                        result.ToolTipElements.Add(new ToolTipElement("Company", epiProfile.Company));
                }

                result.IconCssClass = "userSearch";
                results.Add(result);
            }       

        }

        private static string GetWildCardSymbol()
        {
            string wildcardSymbol = "%";
            ProviderCapabilitySettings settings = null;
            if (Membership.Provider != null && ProviderCapabilities.Providers.TryGetValue(Membership.Provider.GetType(), out settings))
            {
                wildcardSymbol = settings.WildcardSymbol;
            }
            return wildcardSymbol;
        }
       

        #endregion
    }
}
